@@ -20,26 +20,8 @@
 
 from binascii import hexlify as _hexlify
 from collections import namedtuple
-from struct import pack, unpack
 
-try:
-    unicode  # noqa: F821
-    # if Python2, unicode_literals will mess our first (un)pack() argument
-    _pack_str = pack
-    _unpack_str = unpack
-    pack = lambda x, *args: _pack_str(str(x), *args)
-    unpack = lambda x, *args: _unpack_str(str(x), *args)
-
-    is_string = lambda d: isinstance(d, unicode) or isinstance(d, str)  # noqa: F821
-    # no easy way to distinguish between b'' and '' :(
-    # or (isinstance(d, str) \
-    #     and not any((chr(k) in d for k in range(0x00, 0x1F))) \
-    #     and not any((chr(k) in d for k in range(0x80, 0xFF))) \
-    #     )
-except Exception:
-    # this is certainly Python 3
-    # In Py3, unicode and str are equal (the unicode object does not exist)
-    is_string = lambda d: isinstance(d, str)
+is_string = lambda d: isinstance(d, str)
 
 #
 #
@@ -51,6 +33,7 @@ class NamedInt(int):
 
     Caution: comparison with strings will also match this NamedInt's name
     (case-insensitive)."""
+
     def __new__(cls, value, name):
         assert is_string(name)
         obj = int.__new__(cls, value)
@@ -80,8 +63,6 @@ class NamedInt(int):
     def __str__(self):
         return self.name
 
-    __unicode__ = __str__
-
     def __repr__(self):
         return 'NamedInt(%d, %r)' % (int(self), self.name)
 
@@ -99,30 +80,34 @@ class NamedInts:
     if the value already exists in the set (int or string), ValueError will be
     raised.
     """
-    __slots__ = ('__dict__', '_values', '_indexed', '_fallback')
+    __slots__ = ('__dict__', '_values', '_indexed', '_fallback', '_is_sorted')
+
+    def __init__(self, dict=None, **kwargs):
 
-    def __init__(self, **kwargs):
         def _readable_name(n):
             if not is_string(n):
-                raise TypeError('expected (unicode) string, got ' + str(type(n)))
+                raise TypeError('expected string, got ' + str(type(n)))
             return n.replace('__', '/').replace('_', ' ')
 
         # print (repr(kwargs))
-        values = {k: NamedInt(v, _readable_name(k)) for (k, v) in kwargs.items()}
+        elements = dict if dict else kwargs
+        values = {k: NamedInt(v, _readable_name(k)) for (k, v) in elements.items()}
         self.__dict__ = values
-        self._values = sorted(list(values.values()))
+        self._is_sorted = False
+        self._values = list(values.values())
+        self._sort_values()
         self._indexed = {int(v): v for v in self._values}
         # assert len(values) == len(self._indexed)
         # "(%d) %r\n=> (%d) %r" % (len(values), values, len(self._indexed), self._indexed)
         self._fallback = None
 
     @classmethod
-    def list(cls, items, name_generator=lambda x: str(x)):
+    def list(cls, items, name_generator=lambda x: str(x)):  # noqa: B008
         values = {name_generator(x): x for x in items}
         return NamedInts(**values)
 
     @classmethod
-    def range(cls, from_value, to_value, name_generator=lambda x: str(x), step=1):
+    def range(cls, from_value, to_value, name_generator=lambda x: str(x), step=1):  # noqa: B008
         values = {name_generator(x): x for x in range(from_value, to_value + 1, step)}
         return NamedInts(**values)
 
@@ -137,14 +122,20 @@ class NamedInts:
         if unknown_bits:
             yield 'unknown:%06X' % unknown_bits
 
+    def _sort_values(self):
+        self._values = sorted(self._values)
+        self._is_sorted = True
+
     def __getitem__(self, index):
         if isinstance(index, int):
             if index in self._indexed:
                 return self._indexed[int(index)]
-            if self._fallback and isinstance(index, int):
+            if self._fallback:
                 value = NamedInt(index, self._fallback(index))
                 self._indexed[index] = value
-                self._values = sorted(self._values + [value])
+                self._values.append(value)
+                self._is_sorted = False
+                self._sort_values()
                 return value
 
         elif is_string(index):
@@ -153,21 +144,24 @@ class NamedInts:
             return (next((x for x in self._values if str(x) == index), None))
 
         elif isinstance(index, slice):
+            values = self._values if self._is_sorted else sorted(self._values)
+
             if index.start is None and index.stop is None:
-                return self._values[:]
+                return values[:]
 
-            v_start = int(self._values[0]) if index.start is None else int(index.start)
-            v_stop = (self._values[-1] + 1) if index.stop is None else int(index.stop)
+            v_start = int(values[0]) if index.start is None else int(index.start)
+            v_stop = (values[-1] + 1) if index.stop is None else int(index.stop)
 
-            if v_start > v_stop or v_start > self._values[-1] or v_stop <= self._values[0]:
+            if v_start > v_stop or v_start > values[-1] or v_stop <= values[0]:
                 return []
 
-            if v_start <= self._values[0] and v_stop > self._values[-1]:
-                return self._values[:]
+            if v_start <= values[0] and v_stop > values[-1]:
+                return values[:]
 
             start_index = 0
-            stop_index = len(self._values)
-            for i, value in enumerate(self._values):
+            stop_index = len(values)
+
+            for i, value in enumerate(values):
                 if value < v_start:
                     start_index = i + 1
                 elif index.stop is None:
@@ -176,7 +170,7 @@ class NamedInts:
                     stop_index = i
                     break
 
-            return self._values[start_index:stop_index]
+            return values[start_index:stop_index]
 
     def __setitem__(self, index, name):
         assert isinstance(index, int), type(index)
@@ -193,12 +187,16 @@ class NamedInts:
         if int(value) in self._indexed:
             raise ValueError('%d (%s) already known' % (int(value), value))
 
-        self._values = sorted(self._values + [value])
+        self._values.append(value)
+        self._is_sorted = False
+        self._sort_values()
         self.__dict__[str(value)] = value
         self._indexed[int(value)] = value
 
     def __contains__(self, value):
-        if isinstance(value, int):
+        if isinstance(value, NamedInt):
+            return self[value] == value
+        elif isinstance(value, int):
             return value in self._indexed
         elif is_string(value):
             return value in self.__dict__ or value in self._values
@@ -212,6 +210,19 @@ class NamedInts:
     def __repr__(self):
         return 'NamedInts(%s)' % ', '.join(repr(v) for v in self._values)
 
+    def __or__(self, other):
+        return NamedInts(**self.__dict__, **other.__dict__)
+
+
+class UnsortedNamedInts(NamedInts):
+
+    def _sort_values(self):
+        pass
+
+    def __or__(self, other):
+        c = UnsortedNamedInts if isinstance(other, UnsortedNamedInts) else NamedInts
+        return c(**self.__dict__, **other.__dict__)
+
 
 def strhex(x):
     assert x is not None
@@ -219,41 +230,22 @@ def strhex(x):
     return _hexlify(x).decode('ascii').upper()
 
 
-def bytes2int(x):
-    """Convert a bytes string to an int.
-    The bytes are assumed to be in most-significant-first order.
-    """
-    assert isinstance(x, bytes)
-    assert len(x) < 9
-    qx = (b'\x00' * 8) + x
-    result, = unpack('!Q', qx[-8:])
-    # assert x == int2bytes(result, len(x))
-    return result
+def bytes2int(x, signed=False):
+    return int.from_bytes(x, signed=signed, byteorder='big')
 
 
-def int2bytes(x, count=None):
-    """Convert an int to a bytes representation.
-    The bytes are ordered in most-significant-first order.
-    If 'count' is not given, the necessary number of bytes is computed.
-    """
-    assert isinstance(x, int)
-    result = pack('!Q', x)
-    assert isinstance(result, bytes)
-    # assert x == bytes2int(result)
-
-    if count is None:
-        return result.lstrip(b'\x00')
-
-    assert isinstance(count, int)
-    assert count > 0
-    assert x.bit_length() <= count * 8
-    return result[-count:]
+def int2bytes(x, count=None, signed=False):
+    if count:
+        return x.to_bytes(length=count, byteorder='big', signed=signed)
+    else:
+        return x.to_bytes(length=8, byteorder='big', signed=signed).lstrip(b'\x00')
 
 
 class KwException(Exception):
     """An exception that remembers all arguments passed to the constructor.
     They can be later accessed by simple member access.
     """
+
     def __init__(self, **kwargs):
         super().__init__(kwargs)
 
@@ -261,7 +253,7 @@ class KwException(Exception):
         try:
             return super().__getattr__(k)
         except AttributeError:
-            return self.args[0][k]
+            return self.args[0].get(k)  # was self.args[0][k]
 
 
 """Firmware information."""
