@@ -138,6 +138,7 @@ class EventsListener(_threading.Thread):
 
     Incoming packets will be passed to the callback function in sequence.
     """
+
     def __init__(self, receiver, notifications_callback):
         super().__init__(name=self.__class__.__name__ + ':' + receiver.path.split('/')[2])
 
@@ -173,7 +174,7 @@ class EventsListener(_threading.Thread):
                     # _log.debug("read next notification")
                     n = _base.read(self.receiver.handle, _EVENT_READ_TIMEOUT)
                 except _base.NoReceiver:
-                    _log.warning('receiver disconnected')
+                    _log.warning('%s disconnected', self.receiver.name)
                     self.receiver.close()
                     break
 
