@@ -58,7 +58,8 @@ class Receiver:
         self.product_id = device_info.product_id
         product_info = _product_information(self.product_id)
         if not product_info:
-            raise Exception('Unknown receiver type', self.product_id)
+            _log.warning('Unknown receiver type: %s', self.product_id)
+            product_info = {}
         self.receiver_kind = product_info.get('receiver_kind', 'unknown')
 
         # read the serial immediately, so we can find out max_devices
@@ -76,24 +77,18 @@ class Receiver:
                 self.last_id = ord(serial_reply[7:8])
                 if self.max_devices <= 0 or self.max_devices > 6:
                     self.max_devices = product_info.get('max_devices', 1)
-                # TODO _properly_ figure out which receivers do and which don't support unpairing
-                # This code supposes that receivers that don't unpair support a pairing request for device index 0
-                if 'unpair' in product_info:
-                    self.may_unpair = product_info['unpair']
-                else:
-                    self.may_unpair = self.write_register(_R.receiver_pairing) is None
+                self.may_unpair = product_info.get('may_unpair', False)
             else:  # handle receivers that don't have a serial number specially (i.e., c534 and Bolt receivers)
                 self.serial = None
                 self.max_devices = product_info.get('max_devices', 1)
                 self.may_unpair = product_info.get('may_unpair', False)
         self.last_id = self.last_id if self.last_id else self.max_devices
 
-        self.name = product_info.get('name', '')
+        self.name = product_info.get('name', 'Receiver')
         self.re_pairs = product_info.get('re_pairs', False)
         self._str = '<%s(%s,%s%s)>' % (
             self.name.replace(' ', ''), self.path, '' if isinstance(self.handle, int) else 'T', self.handle
         )
-        self.ex100_27mhz_wpid_fix = product_info.get('ex100_27mhz_wpid_fix', False)
 
         self._firmware = None
         self._devices = {}
@@ -179,7 +174,7 @@ class Receiver:
             wpid = _strhex(pair_info[3:5])
             kind = _hidpp10.DEVICE_KIND[ord(pair_info[7:8]) & 0x0F]
             polling_rate = ord(pair_info[2:3])
-        elif self.ex100_27mhz_wpid_fix:  # 27Mhz receiver, fill extracting WPID from udev path
+        elif self.receiver_kind == '27Mz':  # 27Mhz receiver, fill extracting WPID from udev path
             wpid = _hid.find_paired_node_wpid(self.path, n)
             if not wpid:
                 _log.error('Unable to get wpid from udev for device %d of %s', n, self)
