@@ -86,6 +86,7 @@ class ReceiverStatus(dict):
     """The 'runtime' status of a receiver, mostly about the pairing process --
     is the pairing lock open or closed, any pairing errors, etc.
     """
+
     def __init__(self, receiver, changed_callback):
         assert receiver
         self._receiver = receiver
@@ -144,6 +145,7 @@ class DeviceStatus(dict):
     active/inactive, battery charge, lux, etc. It updates them mostly by
     processing incoming notification events from the device itself.
     """
+
     def __init__(self, device, changed_callback):
         assert device
         self._device = device
@@ -158,6 +160,7 @@ class DeviceStatus(dict):
         self.updated = 0
 
     def to_string(self):
+
         def _items():
             comma = False
 
@@ -190,7 +193,7 @@ class DeviceStatus(dict):
 
     __nonzero__ = __bool__
 
-    def set_battery_info(self, level, status, nextLevel=None, voltage=None, timestamp=None):
+    def set_battery_info(self, level, nextLevel, status, voltage, timestamp=None):
         if _log.isEnabledFor(_DEBUG):
             _log.debug('%s: battery %s, %s', self._device, level, status)
 
@@ -237,7 +240,7 @@ class DeviceStatus(dict):
             else:
                 reason = _('Battery: %(percent)d%% (%(status)s)') % {'percent': level, 'status': status.name}
 
-        if changed or reason:
+        if changed or reason or not self._active:  # a battery response means device is active
             # update the leds on the device, if any
             _hidpp10.set_3leds(self._device, level, charging=charging, warning=bool(alert))
             self.changed(active=True, alert=alert, reason=reason, timestamp=timestamp)
@@ -245,35 +248,14 @@ class DeviceStatus(dict):
     # Retrieve and regularize battery status
     def read_battery(self, timestamp=None):
         if self._active:
-            d = self._device
-            assert d
-
-            if d.protocol < 2.0:
-                battery = _hidpp10.get_battery(d)
-                self.set_battery_keys(battery)
-                return
-
-            battery = _hidpp20.get_battery(d)
-            if battery is None:
-                v = _hidpp20.get_voltage(d)
-                if v is not None:
-                    level, status, voltage, _ignore, _ignore = v
-                    self.set_battery_keys((level, status, None), voltage)
-                    return
-
-            # Really unnecessary, if the device has SOLAR_DASHBOARD it should be
-            # broadcasting it's battery status anyway, it will just take a little while.
-            # However, when the device has just been detected, it will not show
-            # any battery status for a while (broadcasts happen every 90 seconds).
-            if battery is None and d.features and _hidpp20.FEATURE.SOLAR_DASHBOARD in d.features:
-                d.feature_request(_hidpp20.FEATURE.SOLAR_DASHBOARD, 0x00, 1, 1)
-                return
+            assert self._device
+            battery = self._device.battery()
             self.set_battery_keys(battery)
 
-    def set_battery_keys(self, battery, voltage=None):
+    def set_battery_keys(self, battery):
         if battery is not None:
-            level, status, nextLevel = battery
-            self.set_battery_info(level, status, nextLevel, voltage)
+            level, nextLevel, status, voltage = battery
+            self.set_battery_info(level, nextLevel, status, voltage)
         elif self.get(KEYS.BATTERY_STATUS, None) is not None:
             self[KEYS.BATTERY_STATUS] = None
             self[KEYS.BATTERY_CHARGING] = None
