@@ -16,5 +16,17 @@
 ## with this program; if not, write to the Free Software Foundation, Inc.,
 ## 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-__version__ = '1.1.5'
-NAME = 'Solaar'
+import pkgutil as _pkgutil
+import subprocess as _subprocess
+import sys as _sys
+
+NAME = 'solaar'
+
+try:
+    __version__ = _subprocess.check_output(['git', 'describe', '--always'], cwd=_sys.path[0],
+                                           stderr=_subprocess.DEVNULL).strip().decode()
+except Exception:
+    try:
+        __version__ = _pkgutil.get_data('solaar', 'commit').strip().decode()
+    except Exception:
+        __version__ = _pkgutil.get_data('solaar', 'version').strip().decode()
