@@ -28,7 +28,6 @@ from threading import Timer as _Timer
 
 import yaml as _yaml
 
-from gi.repository import GLib
 from logitech_receiver.common import NamedInt as _NamedInt
 from solaar import __version__
 
@@ -73,6 +72,7 @@ def _load():
 
 save_timer = None
 save_lock = _Lock()
+defer_saves = False  # don't allow configuration saves to be deferred
 
 
 def save(defer=False):
@@ -86,11 +86,12 @@ def save(defer=False):
         except Exception:
             _log.error('failed to create %s', dirname)
             return
-    if not defer:
+    if not defer or not defer_saves:
         do_save()
     else:
         with save_lock:
             if not save_timer:
+                from gi.repository import GLib
                 save_timer = _Timer(5.0, lambda: GLib.idle_add(do_save))
                 save_timer.start()
 
@@ -134,25 +135,31 @@ def _convert_json(json_dict):
 
 def _cleanup_load(c):
     _config = [__version__]
-    for element in c:
-        if isinstance(element, dict):
-            divert = element.get('divert-keys')
-            if divert:
-                sliding = element.get('dpi-sliding')
-                if sliding:  # convert old-style dpi-sliding setting to divert-keys entry
-                    divert[sliding] = 3
-                    element.pop('dpi-sliding')
-                gestures = element.get('mouse-gestures')
-                if gestures:  # convert old-style mouse-gestures setting to divert-keys entry
-                    divert[gestures] = 2
-                    element.pop('mouse-gestures')
-            # convert to device entries
-            element = _DeviceEntry(**element)
-            _config.append(element)
+    try:
+        for element in c:
+            if isinstance(element, dict):
+                divert = element.get('divert-keys')
+                if divert:
+                    sliding = element.get('dpi-sliding')
+                    if sliding:  # convert old-style dpi-sliding setting to divert-keys entry
+                        divert[int(sliding)] = 3
+                    element.pop('dpi-sliding', None)
+                    gestures = element.get('mouse-gestures')
+                    if gestures:  # convert old-style mouse-gestures setting to divert-keys entry
+                        divert[int(gestures)] = 2
+                    element.pop('mouse-gestures', None)
+                    # remove any string entries (from bad conversions)
+                    element['divert-keys'] = {k: v for k, v in divert.items() if isinstance(k, int)}
+                # convert to device entries
+                element = _DeviceEntry(**element)
+                _config.append(element)
+    except Exception as e:
+        _log.warn('Exception processing config.yaml file, ignoring contents: %s', e)
     return _config
 
 
 class _DeviceEntry(dict):
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
@@ -160,15 +167,15 @@ class _DeviceEntry(dict):
         super().__setitem__(key, value)
         save(defer=True)
 
-    def update(self, device):
+    def update(self, device, modelId):
         if device.name and device.name != self.get(_KEY_NAME):
             super().__setitem__(_KEY_NAME, device.name)
         if device.wpid and device.wpid != self.get(_KEY_WPID):
             super().__setitem__(_KEY_WPID, device.wpid)
         if device.serial and device.serial != '?' and device.serial != self.get(_KEY_SERIAL):
             super().__setitem__(_KEY_SERIAL, device.serial)
-        if device.modelId and device.modelId != self.get(_KEY_MODEL_ID):
-            super().__setitem__(_KEY_MODEL_ID, device.modelId)
+        if modelId and modelId != self.get(_KEY_MODEL_ID):
+            super().__setitem__(_KEY_MODEL_ID, modelId)
         if device.unitId and device.unitId != self.get(_KEY_UNIT_ID):
             super().__setitem__(_KEY_UNIT_ID, device.unitId)
 
@@ -198,10 +205,12 @@ _yaml.add_representer(_NamedInt, named_int_representer)
 
 # A device can be identified by a combination of WPID and serial number (for receiver-connected devices)
 # or a combination of modelId and unitId (for direct-connected devices).
+# But some devices have empty (all zero) modelIds and unitIds.  Use the device name as a backup for the modelId.
 # The worst situation is a receiver-connected device that Solaar has never seen on-line
 # that is directly connected.  Here there is no way to realize that the two devices are the same.
 # So new entries are not created for unseen off-line receiver-connected devices except for those with protocol 1.0
 def persister(device):
+
     def match(wpid, serial, modelId, unitId, c):
         return ((wpid and wpid == c.get(_KEY_WPID) and serial and serial == c.get(_KEY_SERIAL)) or (
             modelId and modelId != '000000000000' and modelId == c.get(_KEY_MODEL_ID) and unitId
@@ -211,8 +220,9 @@ def persister(device):
     if not _config:
         _load()
     entry = None
+    modelId = device.modelId if device.modelId != '000000000000' else device.name if device.modelId else None
     for c in _config:
-        if isinstance(c, _DeviceEntry) and match(device.wpid, device.serial, device.modelId, device.unitId, c):
+        if isinstance(c, _DeviceEntry) and match(device.wpid, device.serial, modelId, device.unitId, c):
             entry = c
             break
     if not entry:
@@ -220,9 +230,11 @@ def persister(device):
             if _log.isEnabledFor(_INFO):
                 _log.info('not setting up persister for offline device %s with missing serial number', device.name)
             return
+        if _log.isEnabledFor(_INFO):
+            _log.info('setting up persister for device %s', device.name)
         entry = _DeviceEntry()
         _config.append(entry)
-    entry.update(device)
+    entry.update(device, modelId)
     return entry
 
 
