@@ -28,7 +28,6 @@ from solaar import NAME as _NAME
 
 def _find_locale_path(lc_domain):
     import os.path as _path
-
     import sys as _sys
     prefix_share = _path.normpath(_path.join(_path.realpath(_sys.path[0]), '..'))
     src_share = _path.normpath(_path.join(_path.realpath(_sys.path[0]), '..', 'share'))
@@ -59,10 +58,5 @@ _gettext.bindtextdomain(_LOCALE_DOMAIN, path)
 _gettext.textdomain(_LOCALE_DOMAIN)
 _gettext.install(_LOCALE_DOMAIN)
 
-try:
-    unicode  # noqa: F821
-    _ = lambda x: _gettext.gettext(x).decode('UTF-8')
-    ngettext = lambda *x: _gettext.ngettext(*x).decode('UTF-8')
-except Exception:
-    _ = _gettext.gettext
-    ngettext = _gettext.ngettext
+_ = _gettext.gettext
+ngettext = _gettext.ngettext
