@@ -69,6 +69,7 @@ def _ghost(device):
 class ReceiverListener(_listener.EventsListener):
     """Keeps the status of a Receiver.
     """
+
     def __init__(self, receiver, status_changed_callback):
         super().__init__(receiver, self._notifications_handler)
         # no reason to enable polling yet
@@ -85,10 +86,10 @@ class ReceiverListener(_listener.EventsListener):
     def has_started(self):
         if _log.isEnabledFor(_INFO):
             _log.info('%s: notifications listener has started (%s)', self.receiver, self.receiver.handle)
-        notification_flags = self.receiver.enable_connection_notifications()
-        assert self.receiver.isDevice or (notification_flags & _hidpp10.NOTIFICATION_FLAG.wireless), \
+        nfs = self.receiver.enable_connection_notifications()
+        assert self.receiver.isDevice or ((nfs if nfs else 0) & _hidpp10.NOTIFICATION_FLAG.wireless), \
             'Receiver on %s does not support connection notifications, GUI will not show it' % self.receiver.path
-        self.receiver.status[_status.KEYS.NOTIFICATION_FLAGS] = notification_flags
+        self.receiver.status[_status.KEYS.NOTIFICATION_FLAGS] = nfs
         self.receiver.notify_devices()
         self._status_changed(self.receiver)  # , _status.ALERT.NOTIFICATION)
 
@@ -198,8 +199,14 @@ class ReceiverListener(_listener.EventsListener):
                 _log.debug('Notification %s via device %s being ignored.', n, self.receiver)
             return
 
+        # DJ pairing notification - ignore - hid++ 1.0 pairing notification is all that is needed
+        if n.sub_id == 0x41 and n.report_id == _base.DJ_MESSAGE_ID:
+            if _log.isEnabledFor(_INFO):
+                _log.info('ignoring DJ pairing notification %s', n)
+            return
+
         # a device notification
-        if not (0 < n.devnumber <= self.receiver.max_devices):
+        if not (0 < n.devnumber <= 16):  # some receivers have devices past their max # devices
             if _log.isEnabledFor(_WARNING):
                 _log.warning('Unexpected device number (%s) in notification %s.', n.devnumber, n)
             return
@@ -218,12 +225,7 @@ class ReceiverListener(_listener.EventsListener):
         if n.sub_id == 0x40 and not already_known:
             return  # disconnecting something that is not known - nothing to do
 
-        if n.sub_id == 0x41 and n.report_id == _base.DJ_MESSAGE_ID:
-            # DJ pairing notification - ignore - hid++ 1.0 pairing notification is all that is needed
-            if _log.isEnabledFor(_INFO):
-                _log.info('ignoring DJ pairing notification %s', n)
-            return
-        elif n.sub_id == 0x41:
+        if n.sub_id == 0x41:
             if not already_known:
                 if n.address == 0x0A and not self.receiver.receiver_kind == 'bolt':
                     # some Nanos send a notification even if no new pairing - check that there really is a device there
@@ -274,8 +276,6 @@ class ReceiverListener(_listener.EventsListener):
     def __str__(self):
         return '<ReceiverListener(%s,%s)>' % (self.receiver.path, self.receiver.handle)
 
-    __unicode__ = __str__
-
 
 #
 #
@@ -310,9 +310,7 @@ def start_all():
 
     if _log.isEnabledFor(_INFO):
         _log.info('starting receiver listening threads')
-    for device_info in _base.receivers():
-        _process_receiver_event('add', device_info)
-    for device_info in _base.wired_devices():
+    for device_info in _base.receivers_and_devices():
         _process_receiver_event('add', device_info)
 
 
@@ -342,19 +340,19 @@ def ping_all(resuming=False):
         _log.info('ping all devices%s', ' when resuming' if resuming else '')
     for l in _all_listeners.values():
         if l.receiver.isDevice:
-            if resuming:
-                l.receiver.status._active = False
+            if resuming and hasattr(l.receiver, 'status'):
+                l.receiver.status._active = None  # ensure that settings are pushed
             if l.receiver.ping():
-                l.receiver.status.changed(active=True)
+                l.receiver.status.changed(active=True, push=True)
             l._status_changed(l.receiver)
         else:
             count = l.receiver.count()
             if count:
                 for dev in l.receiver:
-                    if resuming:
-                        dev.status._active = False
+                    if resuming and hasattr(dev, 'status'):
+                        dev.status._active = None  # ensure that settings are pushed
                     if dev.ping():
-                        dev.status.changed(active=True)
+                        dev.status.changed(active=True, push=True)
                     l._status_changed(dev)
                     count -= 1
                     if not count:
@@ -400,8 +398,8 @@ def _process_receiver_event(action, device_info):
             # (It would be easier to use pylibacl but adding the pylibacl dependencies
             # for this special case is not good.)
             try:
-                import subprocess
                 import re
+                import subprocess
                 output = subprocess.check_output(['/usr/bin/getfacl', '-p', device_info.path])
                 if not re.search(b'user:.+:', output):
                     _error_callback('permissions', device_info.path)
